# This is a sample Python script.
import os
import sys
import threading
from PyQt5.QtCore import Qt
from PyQt5 import QtWidgets,QtGui
from PyQt5.QtGui import QIcon
from PyQt5.QtWidgets import QApplication, QStyleFactory
import nuitka
import subprocess
import shutil

try:
	import mainui
except:
	from . import mainui
	

class MainGui(mainui.Ui_MainWindow,	QtWidgets.QMainWindow):
	def __init__(self,parent=None):
		super(MainGui, self).__init__(parent)
		self.setupUi(self)
		self.setWindowTitle( "EasyNuitka")
		self.pushButton.clicked.connect(self.choose_main_py)
		self.pushButton_2.clicked.connect(self.set_output_path)
		self.pushButton_7.clicked.connect(self.Multithreading_command)
		self.pushButton_4.clicked.connect(self.follow_import_to)
		self.pushButton_12.clicked.connect(self.follow_import_to_remove)
		self.pushButton_20.clicked.connect(self.set_icon)
		self.pushButton_19.clicked.connect(self.remove_icon)
		self.pushButton_9.clicked.connect(self.quit)
		self.pushButton_3.clicked.connect(self.nofollow_import_to)
		self.pushButton_10.clicked.connect(self.nofollow_import_to_remove)
		self.pushButton_17.clicked.connect(self.include_package_remove)
		self.chekbox_clicked_init()
		self.command_dict={}
		self.command_str=None
		self.main_name=None
		self.outputpath="./"
		self.follow_import_to_document_str=""
		self.nofollow_import_to_document_str=""
		self.iconname=None
		self.iconpath=""
		self.compile_module_path=None
		self.statusbar.showMessage("The software runs normally")
	def choose_main_py(self):
		try:
			if not self.checkBox_7.isChecked():
				file = QtWidgets.QFileDialog.getOpenFileName(self,
															 "choose main.py", "./",
															 "All Files (*.py);;Text Files (*.py)")
				self.filenpath = file[0]
				self.lineEdit.setText(file[0])
				self.main_name = self.lineEdit.setText(file[0])
				self.filename = self.filenpath.split("/")[-1]
				self.filenpath = self.filenpath.replace(self.filename, "")
				self.dish = self.filenpath[0:2]
				self.statusbar.showMessage("File selected successfully")

			else :
				directory = QtWidgets.QFileDialog.getExistingDirectory(self, "choose compile module dir", "./")
				self.compile_module_path=directory
				self.lineEdit.setText(directory)
				self.lineEdit_9.setText(self.compile_module_path.split("/")[-1])
				self.statusbar.showMessage("Output directory set successfully")


		except Exception as e:
			self.statusbar.showMessage("File selection failed")
			print(e)
	def set_output_path(self):
		try:
			directory = QtWidgets.QFileDialog.getExistingDirectory(self, "getExistingDirectory", "./")
			self.outputpath=directory
			self.lineEdit_2.setText(directory)
			self.statusbar.showMessage("Output directory set successfully")
		except Exception as e:
			self.statusbar.showMessage("Output directory setting failed")
			pass
	def get_package_method(self):
		#--follow-imports
		if self.checkBox.isChecked():
			self.lineEdit_3.setEnabled(False)
			self.lineEdit_4.setEnabled(False)
			self.checkBox_8.setEnabled(False)

			self.command_dict[self.checkBox]="--follow-imports"
			#print(self.command_dict)
		elif not self.checkBox.isChecked():
			self.lineEdit_3.setEnabled(True)
			self.lineEdit_4.setEnabled(True)
			self.checkBox_8.setEnabled(True)
			self.command_dict[self.checkBox] = ""
		#--nofollow-imports
		if self.checkBox_8.isChecked():
			self.checkBox.setEnabled(False)
			self.command_dict[self.checkBox_8] = "--nofollow-imports"
			#print(self.command_dict)
		elif not self.checkBox_8.isChecked():
			self.checkBox.setEnabled(True)
			self.command_dict[self.checkBox_8] = ""
		#--module
		if self.checkBox_7.isChecked():
			self.checkBox.setEnabled(False)
			self.checkBox_8.setEnabled(False)
			self.checkBox_3.setEnabled(False)
			self.checkBox_4.setEnabled(False)
			self.lineEdit_3.setEnabled(False)
			self.lineEdit_4.setEnabled(False)
			self.lineEdit_5.setEnabled(False)
			self.lineEdit_8.setEnabled(False)
			self.lineEdit_6.setEnabled(False)
			self.lineEdit_9.setEnabled(True)
			self.radioButton.setEnabled(False)
			self.radioButton_2.setEnabled(False)
			self.command_dict[self.checkBox_7] = "--module"
			#print(self.command_dict)
		elif not self.checkBox_7.isChecked():
			self.checkBox_3.setEnabled(True)
			self.checkBox_4.setEnabled(True)
			self.lineEdit_3.setEnabled(True)
			self.lineEdit_4.setEnabled(True)
			self.lineEdit_5.setEnabled(True)
			self.lineEdit_8.setEnabled(True)
			self.lineEdit_6.setEnabled(True)
			self.lineEdit_9.setEnabled(False)
			self.radioButton.setEnabled(True)
			self.radioButton_2.setEnabled(True)
			self.checkBox_3.setEnabled(True)
			self.checkBox_4.setEnabled(True)
			if self.checkBox.isChecked():
				self.checkBox_8.setEnabled(False)
			if self.checkBox_8.isChecked():
				self.checkBox.setEnabled(False)

			self.command_dict[self.checkBox_7] = ""
		#--standalone
		if self.checkBox_3.isChecked():
			self.checkBox_4.setEnabled(False)
			self.checkBox_7.setEnabled(False)
			self.command_dict[self.checkBox_3] = "--standalone"
		elif not self.checkBox_3.isChecked() and not self.checkBox_7.isChecked():
			self.checkBox_7.setEnabled(True)
			self.checkBox_4.setEnabled(True)
			self.command_dict[self.checkBox_3] = ""
		#--onefile
		if self.checkBox_4.isChecked():
			self.checkBox_3.setEnabled(False)
			self.checkBox_7.setEnabled(False)
			self.command_dict[self.checkBox_4] = "--onefile"
		elif not self.checkBox_4.isChecked() and not self.checkBox_7.isChecked() :
			self.checkBox_3.setEnabled(True)
			if not self.checkBox_3.isChecked():
				self.checkBox_7.setEnabled(True)
			self.command_dict[self.checkBox_4] = ""

		#--mingw64
		if self.checkBox_2.isChecked():
			self.checkBox_10.setEnabled(False)
			self.command_dict[self.checkBox_2] = "--mingw64"
		else:
			self.checkBox_10.setEnabled(True)
			self.command_dict[self.checkBox_2] = ""
		#--show-memory
		if self.checkBox_5.isChecked():
			self.command_dict[self.checkBox_5] = "--show-memory"
		else:
			self.command_dict[self.checkBox_5] = ""
		#--show-progress
		if self.checkBox_6.isChecked():
			self.command_dict[self.checkBox_6] = "--show-progress"
		else:
			self.command_dict[self.checkBox_6] = ""
		#-msvc64
		if self.checkBox_10.isChecked():
			self.checkBox_2.setEnabled(False)
			self.command_dict[self.checkBox_10] = "-msvc64"
		else:
			self.checkBox_2.setEnabled(True)
			self.command_dict[self.checkBox_10] = ""
		#--include-plugin-pyqt5
		if self.checkBox_9.isChecked():
			self.command_dict[self.checkBox_9] = "--plugin-enable=pyqt5"
		else:
			self.command_dict[self.checkBox_9] = ""
		#--include-plugin-numpy
		if self.checkBox_17.isChecked():
			self.command_dict[self.checkBox_17] = "--plugin-enable=numpy"
		else:
			self.command_dict[self.checkBox_17] = ""
		#--include-plugin-torch
		if self.checkBox_20.isChecked():
			self.command_dict[self.checkBox_20] = "--plugin-enable=torch"
		else:
			self.command_dict[self.checkBox_20] = ""
		#--include-plugin-matplotlib
		if self.checkBox_11.isChecked():
			self.command_dict[self.checkBox_11] = "--plugin-enable=matplotlib"
		else:
			self.command_dict[self.checkBox_11] = ""
		#--include-plugin-pyqt6
		if self.checkBox_13.isChecked():
			self.command_dict[self.checkBox_13] = "--plugin-enable=pyqt6"
		else:
			self.command_dict[self.checkBox_13] = ""
		#--include-plugin-pyside2
		if self.checkBox_15.isChecked():
			self.command_dict[self.checkBox_15] = "--plugin-enable=pyside2"
		else:
			self.command_dict[self.checkBox_15] = ""
		#--include-plugin-pyside6
		if self.checkBox_12.isChecked():
			self.command_dict[self.checkBox_12] = "--plugin-enable=pyside6"
		else:
			self.command_dict[self.checkBox_12] = ""
		#--include-plugin-no-qt5
		if self.checkBox_18.isChecked():
			self.command_dict[self.checkBox_18] = "--plugin-enable=no-qt5"
		else:
			self.command_dict[self.checkBox_18] = ""
		#--include-plugin-upx
		if self.checkBox_22.isChecked():
			self.command_dict[self.checkBox_22] = "--plugin-enable=upx"
		else:
			self.command_dict[self.checkBox_22] = ""
		#--include-plugin-tensorflow
		if self.checkBox_19.isChecked():
			self.command_dict[self.checkBox_19] = "--plugin-enable=tensorflow"
		else:
			self.command_dict[self.checkBox_19] = ""
		#--include-plugin-pywebview
		if self.checkBox_25.isChecked():
			self.command_dict[self.checkBox_25] = "--plugin-enable=pywebview"
		else:
			self.command_dict[self.checkBox_25] = ""
		#--include-plugin-tk-inter
		if self.checkBox_24.isChecked():
			self.command_dict[self.checkBox_24] = "--plugin-enable=tk-inter"
		else:
			self.command_dict[self.checkBox_24] = ""
		#--include-plugin-trio
		if self.checkBox_23.isChecked():
			self.command_dict[self.checkBox_23] = "--plugin-enable=trio"
		else:
			self.command_dict[self.checkBox_23] = ""
		#--include-plugin-multiprocessing
		if self.checkBox_14.isChecked():
			self.command_dict[self.checkBox_14] = "--plugin-enable=multiprocessing"
		else:
			self.command_dict[self.checkBox_14] = ""
		#--windows-disable-console
		if self.radioButton.isChecked():
			self.command_dict[self.radioButton] = "--windows-disable-console"
		if self.radioButton_2.isChecked():
			self.command_dict[self.radioButton_2] = ""
		#Default Enabled
		self.lineEdit_5.setEnabled(False)
		self.lineEdit_8.setEnabled(False)

		self.statusbar.showMessage("Selection succeeded")
	def Multithreading_command(self):
		t=threading.Thread(target=self.excute_command,args=())
		t.start()
		self.statusbar.showMessage("packaging is finishing")
	def excute_command(self):
		try:
			self.command_str="python -m nuitka "
			for command in self.command_dict.keys():
				if self.command_dict[command]=="":
					continue
				if self.command_dict[command]=="--module":
					self.command_dict[command]="--module "+self.compile_module_path.split("/")[-1]+" "+"--include-package="+\
											   self.lineEdit_9.text()
				self.command_str+=self.command_dict[command]+" "
			if self.follow_import_to_document_str!="":
				self.command_str += "--follow-import-to=" + self.follow_import_to_document_str[0:len(self.follow_import_to_document_str)-1] + " "
			if self.follow_import_to_document_str!="":
				self.command_str+="--nofollow-import-to="+self.follow_import_to_document_str+" "
			self.command_str+="--output-dir="+self.outputpath+" "
			if self.iconname!=None:
				self.command_str+="--windows-icon-from-ico="+self.iconname+" "
			if not self.checkBox_7.isChecked():
				self.command_str+=self.filename

			print(self.command_str)
			if not self.checkBox_7.isChecked():
				os.chdir(self.filenpath)
			else:
				os.chdir(self.compile_module_path)
				os.chdir("../")
			os.system(self.command_str)
			self.statusbar.showMessage("Please wait to start packaging......")
		except Exception as e:
			self.statusbar.showMessage(e)
			#print(e)

	def chekbox_clicked_init(self):
		self.package_method=[]
		self.checkBox_dict = {self.checkBox: "--follow-imports", self.checkBox_8: "--nofollow-imports",
							  self.checkBox_7: "--module",
							  self.checkBox_3: "--standalone", self.checkBox_4: "--onefile",
							  self.checkBox_2: "--mingw64", self.checkBox_5: "--show-memory",
							  self.checkBox_6: "--show-progress", self.checkBox_10: "-msvc64",
							  self.checkBox_9: "--include-plugin-pyqt5",
							  self.checkBox_17: "--include-plugin-numpy",self.checkBox_20:"--include-plugin-torch",
							  self.checkBox_11:"--include-plugin-matplotlib",self.checkBox_13:"--include-plugin-pyqt6",
							  self.checkBox_15:"--include-plugin-pyside2",self.checkBox_12:"--include-plugin-pyside6",
							  self.checkBox_18:"--include-plugin-no-qt5",self.checkBox_22:"--include-plugin-upx",
							  self.checkBox_19:"--include-plugin-tensorflow",self.checkBox_25:"--include-plugin-pywebview",
							  self.checkBox_24:"--include-plugin-tk-inter",self.checkBox_23:"--include-plugin-trio",
							  self.checkBox_14:"--include-plugin-multiprocessing",self.radioButton:"--windows-disable-console",
							  self.radioButton_2:""}
		for check in self.checkBox_dict.keys():
			try:
				check.clicked.connect(self.get_package_method)
			except:
				pass
		self.lineEdit_9.setEnabled(False)
	def nofollow_import_to(self):
		self.follow_import_to_document_str=self.lineEdit_3.text()
		self.statusbar.showMessage("add module to nofollow_import_to ")
	def nofollow_import_to_remove(self):
		self.lineEdit_3.setText("Enter module/package ;Separate them with commas")
		self.follow_import_to_document_str=""
		self.statusbar.showMessage("Removed")
	def follow_import_to(self):
		try:
			directory = QtWidgets.QFileDialog.getExistingDirectory(self, "getExistingDirectory", "./")
			self.follow_import_to_document = directory.split("/")[-1]
			self.follow_import_to_document_str+=self.follow_import_to_document+","
			self.lineEdit_4.setText(self.follow_import_to_document_str)
		except Exception as e:
			print(e)
			pass
	def follow_import_to_remove(self):
		try:
			self.lineEdit_4.setText("Select the folder you want to compile")
		except Exception as e:
			self.statusbar.showMessage("Removed")
			pass
	def include_data_files(self):
		pass
	def set_icon(self):
		try:
			if not self.checkBox_7.isChecked():
				file = QtWidgets.QFileDialog.getOpenFileName(self,
															 "getOpenFileName", "./",
															 "All Files (*);;Text Files (*)")
				self.iconpath = file[0]
				self.lineEdit_6.setText(self.iconpath)
				src = self.iconpath
				dist = self.filenpath + src.split("/")[-1]
				if not os.path.exists(dist):
					shutil.copyfile(src, dist)
				self.iconname = src.split("/")[-1]

		except Exception as e:
			print(e)
	def remove_icon(self):
		self.lineEdit_6.setText("Select  icon")
		self.statusbar.showMessage("Removed")

	def include_data_files(self):
		try:
			file = QtWidgets.QFileDialog.getOpenFileName(self,
														 "getOpenFileName", "./",
														 "All Files (*);;Text Files (*)")
			self.include_data_files=file[0]
		except Exception as e:
			pass

	def include_package_remove(self):
		self.lineEdit_9.setText("Default to the entire module")
	def quit(self):
		sys.exit()
# Press the green button in the gutter to run the script.
if __name__ == '__main__':
	QApplication.setAttribute(Qt.AA_EnableHighDpiScaling)
	app = QtWidgets.QApplication(sys.argv)
	QApplication.setStyle(QStyleFactory.create('Fusion'))
	win = MainGui()
	win.show()
	sys.exit(app.exec_())

# See PyCharm help at https://www.jetbrains.com/help/pycharm/



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainui.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets
import resource

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(774, 774)
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(12)
        MainWindow.setFont(font)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/png/icon/Nuitka.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox.setGeometry(QtCore.QRect(20, 90, 731, 141))
        self.groupBox.setObjectName("groupBox")
        self.checkBox = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox.setGeometry(QtCore.QRect(20, 40, 151, 17))
        self.checkBox.setObjectName("checkBox")
        self.checkBox_2 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_2.setGeometry(QtCore.QRect(200, 100, 111, 21))
        self.checkBox_2.setObjectName("checkBox_2")
        self.checkBox_3 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_3.setGeometry(QtCore.QRect(200, 40, 141, 17))
        self.checkBox_3.setObjectName("checkBox_3")
        self.checkBox_4 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_4.setGeometry(QtCore.QRect(200, 70, 141, 17))
        self.checkBox_4.setObjectName("checkBox_4")
        self.checkBox_5 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_5.setGeometry(QtCore.QRect(330, 40, 151, 21))
        self.checkBox_5.setObjectName("checkBox_5")
        self.checkBox_6 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_6.setGeometry(QtCore.QRect(330, 70, 151, 17))
        self.checkBox_6.setObjectName("checkBox_6")
        self.checkBox_7 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_7.setGeometry(QtCore.QRect(20, 100, 91, 17))
        self.checkBox_7.setObjectName("checkBox_7")
        self.checkBox_8 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_8.setGeometry(QtCore.QRect(20, 70, 171, 17))
        self.checkBox_8.setObjectName("checkBox_8")
        self.checkBox_10 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_10.setGeometry(QtCore.QRect(330, 100, 101, 21))
        self.checkBox_10.setObjectName("checkBox_10")
        self.checkBox_9 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_9.setGeometry(QtCore.QRect(500, 40, 221, 21))
        self.checkBox_9.setObjectName("checkBox_9")
        self.checkBox_17 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_17.setGeometry(QtCore.QRect(500, 70, 211, 17))
        self.checkBox_17.setObjectName("checkBox_17")
        self.checkBox_20 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_20.setGeometry(QtCore.QRect(500, 100, 211, 17))
        self.checkBox_20.setObjectName("checkBox_20")
        self.groupBox_2 = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_2.setGeometry(QtCore.QRect(20, 410, 731, 241))
        self.groupBox_2.setObjectName("groupBox_2")
        self.label_3 = QtWidgets.QLabel(self.groupBox_2)
        self.label_3.setGeometry(QtCore.QRect(20, 30, 171, 21))
        self.label_3.setObjectName("label_3")
        self.lineEdit_3 = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit_3.setGeometry(QtCore.QRect(200, 30, 331, 21))
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(9)
        self.lineEdit_3.setFont(font)
        self.lineEdit_3.setObjectName("lineEdit_3")
        self.pushButton_3 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_3.setGeometry(QtCore.QRect(550, 30, 75, 23))
        self.pushButton_3.setObjectName("pushButton_3")
        self.pushButton_10 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_10.setGeometry(QtCore.QRect(640, 30, 75, 23))
        self.pushButton_10.setObjectName("pushButton_10")
        self.label_5 = QtWidgets.QLabel(self.groupBox_2)
        self.label_5.setGeometry(QtCore.QRect(20, 150, 271, 21))
        self.label_5.setObjectName("label_5")
        self.lineEdit_4 = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit_4.setGeometry(QtCore.QRect(200, 60, 331, 21))
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(9)
        self.lineEdit_4.setFont(font)
        self.lineEdit_4.setObjectName("lineEdit_4")
        self.pushButton_4 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_4.setGeometry(QtCore.QRect(550, 60, 75, 23))
        self.pushButton_4.setObjectName("pushButton_4")
        self.pushButton_12 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_12.setGeometry(QtCore.QRect(640, 60, 75, 23))
        self.pushButton_12.setObjectName("pushButton_12")
        self.label_6 = QtWidgets.QLabel(self.groupBox_2)
        self.label_6.setGeometry(QtCore.QRect(20, 90, 271, 21))
        self.label_6.setObjectName("label_6")
        self.lineEdit_5 = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit_5.setEnabled(False)
        self.lineEdit_5.setGeometry(QtCore.QRect(200, 90, 331, 21))
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(9)
        self.lineEdit_5.setFont(font)
        self.lineEdit_5.setObjectName("lineEdit_5")
        self.pushButton_5 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_5.setGeometry(QtCore.QRect(550, 90, 75, 23))
        self.pushButton_5.setObjectName("pushButton_5")
        self.pushButton_14 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_14.setGeometry(QtCore.QRect(640, 90, 75, 23))
        self.pushButton_14.setObjectName("pushButton_14")
        self.label_7 = QtWidgets.QLabel(self.groupBox_2)
        self.label_7.setGeometry(QtCore.QRect(20, 120, 151, 21))
        self.label_7.setObjectName("label_7")
        self.lineEdit_8 = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit_8.setEnabled(False)
        self.lineEdit_8.setGeometry(QtCore.QRect(200, 120, 331, 21))
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(9)
        self.lineEdit_8.setFont(font)
        self.lineEdit_8.setObjectName("lineEdit_8")
        self.pushButton_15 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_15.setGeometry(QtCore.QRect(550, 120, 75, 23))
        self.pushButton_15.setObjectName("pushButton_15")
        self.pushButton_16 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_16.setGeometry(QtCore.QRect(640, 120, 75, 23))
        self.pushButton_16.setObjectName("pushButton_16")
        self.label_8 = QtWidgets.QLabel(self.groupBox_2)
        self.label_8.setGeometry(QtCore.QRect(20, 60, 171, 21))
        self.label_8.setObjectName("label_8")
        self.lineEdit_9 = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit_9.setGeometry(QtCore.QRect(200, 150, 331, 21))
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(9)
        self.lineEdit_9.setFont(font)
        self.lineEdit_9.setObjectName("lineEdit_9")
        self.pushButton_17 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_17.setGeometry(QtCore.QRect(640, 150, 75, 23))
        self.pushButton_17.setObjectName("pushButton_17")
        self.pushButton_18 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_18.setGeometry(QtCore.QRect(550, 150, 75, 23))
        self.pushButton_18.setObjectName("pushButton_18")
        self.label_4 = QtWidgets.QLabel(self.groupBox_2)
        self.label_4.setGeometry(QtCore.QRect(20, 180, 61, 21))
        self.label_4.setObjectName("label_4")
        self.lineEdit_6 = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit_6.setGeometry(QtCore.QRect(200, 180, 331, 21))
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(9)
        self.lineEdit_6.setFont(font)
        self.lineEdit_6.setObjectName("lineEdit_6")
        self.pushButton_19 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_19.setGeometry(QtCore.QRect(640, 180, 75, 23))
        self.pushButton_19.setObjectName("pushButton_19")
        self.pushButton_20 = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButton_20.setGeometry(QtCore.QRect(550, 180, 75, 23))
        self.pushButton_20.setObjectName("pushButton_20")
        self.radioButton = QtWidgets.QRadioButton(self.groupBox_2)
        self.radioButton.setGeometry(QtCore.QRect(200, 210, 89, 17))
        self.radioButton.setObjectName("radioButton")
        self.radioButton_2 = QtWidgets.QRadioButton(self.groupBox_2)
        self.radioButton_2.setGeometry(QtCore.QRect(360, 210, 101, 17))
        self.radioButton_2.setObjectName("radioButton_2")
        self.pushButton_7 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_7.setGeometry(QtCore.QRect(140, 680, 131, 31))
        self.pushButton_7.setObjectName("pushButton_7")
        self.pushButton_8 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_8.setGeometry(QtCore.QRect(340, 680, 101, 31))
        self.pushButton_8.setObjectName("pushButton_8")
        self.pushButton_9 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_9.setGeometry(QtCore.QRect(500, 680, 101, 31))
        self.pushButton_9.setObjectName("pushButton_9")
        self.layoutWidget = QtWidgets.QWidget(self.centralwidget)
        self.layoutWidget.setGeometry(QtCore.QRect(20, 10, 721, 33))
        self.layoutWidget.setObjectName("layoutWidget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.layoutWidget)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(self.layoutWidget)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.lineEdit = QtWidgets.QLineEdit(self.layoutWidget)
        self.lineEdit.setObjectName("lineEdit")
        self.horizontalLayout.addWidget(self.lineEdit)
        self.pushButton = QtWidgets.QPushButton(self.layoutWidget)
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout.addWidget(self.pushButton)
        self.layoutWidget1 = QtWidgets.QWidget(self.centralwidget)
        self.layoutWidget1.setGeometry(QtCore.QRect(21, 50, 721, 33))
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.layoutWidget1)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_2 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_2.addWidget(self.label_2)
        self.lineEdit_2 = QtWidgets.QLineEdit(self.layoutWidget1)
        self.lineEdit_2.setObjectName("lineEdit_2")
        self.horizontalLayout_2.addWidget(self.lineEdit_2)
        self.pushButton_2 = QtWidgets.QPushButton(self.layoutWidget1)
        self.pushButton_2.setObjectName("pushButton_2")
        self.horizontalLayout_2.addWidget(self.pushButton_2)
        self.groupBox_3 = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_3.setGeometry(QtCore.QRect(20, 240, 731, 161))
        self.groupBox_3.setObjectName("groupBox_3")
        self.checkBox_11 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_11.setGeometry(QtCore.QRect(20, 30, 231, 21))
        self.checkBox_11.setObjectName("checkBox_11")
        self.checkBox_13 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_13.setGeometry(QtCore.QRect(260, 30, 201, 21))
        self.checkBox_13.setObjectName("checkBox_13")
        self.checkBox_15 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_15.setGeometry(QtCore.QRect(500, 30, 211, 21))
        self.checkBox_15.setObjectName("checkBox_15")
        self.checkBox_12 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_12.setGeometry(QtCore.QRect(20, 60, 221, 21))
        self.checkBox_12.setObjectName("checkBox_12")
        self.checkBox_18 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_18.setGeometry(QtCore.QRect(260, 60, 201, 21))
        self.checkBox_18.setObjectName("checkBox_18")
        self.checkBox_19 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_19.setGeometry(QtCore.QRect(20, 90, 231, 21))
        self.checkBox_19.setObjectName("checkBox_19")
        self.checkBox_22 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_22.setGeometry(QtCore.QRect(500, 60, 201, 21))
        self.checkBox_22.setObjectName("checkBox_22")
        self.checkBox_23 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_23.setGeometry(QtCore.QRect(20, 120, 201, 21))
        self.checkBox_23.setObjectName("checkBox_23")
        self.checkBox_24 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_24.setGeometry(QtCore.QRect(500, 90, 211, 21))
        self.checkBox_24.setObjectName("checkBox_24")
        self.checkBox_25 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_25.setGeometry(QtCore.QRect(260, 90, 241, 21))
        self.checkBox_25.setObjectName("checkBox_25")
        self.checkBox_14 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_14.setGeometry(QtCore.QRect(260, 120, 281, 21))
        self.checkBox_14.setObjectName("checkBox_14")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 774, 27))
        self.menubar.setObjectName("menubar")
        self.menu = QtWidgets.QMenu(self.menubar)
        self.menu.setObjectName("menu")
        self.menu_2 = QtWidgets.QMenu(self.menubar)
        self.menu_2.setObjectName("menu_2")
        self.menu_3 = QtWidgets.QMenu(self.menubar)
        self.menu_3.setObjectName("menu_3")
        self.menu_4 = QtWidgets.QMenu(self.menubar)
        self.menu_4.setObjectName("menu_4")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        font = QtGui.QFont()
        font.setFamily("微软雅黑")
        font.setPointSize(8)
        self.statusbar.setFont(font)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.menubar.addAction(self.menu.menuAction())
        self.menubar.addAction(self.menu_2.menuAction())
        self.menubar.addAction(self.menu_3.menuAction())
        self.menubar.addAction(self.menu_4.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "EasyNuitka"))
        self.groupBox.setTitle(_translate("MainWindow", "package method"))
        self.checkBox.setText(_translate("MainWindow", "--follow-imports"))
        self.checkBox_2.setText(_translate("MainWindow", "--mingw64"))
        self.checkBox_3.setText(_translate("MainWindow", "--standalone"))
        self.checkBox_4.setText(_translate("MainWindow", "--onefile"))
        self.checkBox_5.setText(_translate("MainWindow", "--show-memory"))
        self.checkBox_6.setText(_translate("MainWindow", "--show-progress"))
        self.checkBox_7.setText(_translate("MainWindow", "--module "))
        self.checkBox_8.setText(_translate("MainWindow", "--nofollow-imports"))
        self.checkBox_10.setText(_translate("MainWindow", "--msvc64"))
        self.checkBox_9.setText(_translate("MainWindow", "--include-plugin-pyqt5"))
        self.checkBox_17.setText(_translate("MainWindow", "--include-plugin-numpy"))
        self.checkBox_20.setText(_translate("MainWindow", "--include-plugin-torch"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Parameter Setting"))
        self.label_3.setText(_translate("MainWindow", "--nofollow-import-to"))
        self.lineEdit_3.setText(_translate("MainWindow", "Enter module/package ;Separate them with commas"))
        self.pushButton_3.setText(_translate("MainWindow", "Add"))
        self.pushButton_10.setText(_translate("MainWindow", "Remove"))
        self.label_5.setText(_translate("MainWindow", "--include-package"))
        self.lineEdit_4.setText(_translate("MainWindow", "Select the folder you want to compile"))
        self.pushButton_4.setText(_translate("MainWindow", "Add"))
        self.pushButton_12.setText(_translate("MainWindow", "Remove"))
        self.label_6.setText(_translate("MainWindow", "--include-data-files"))
        self.pushButton_5.setText(_translate("MainWindow", "Add"))
        self.pushButton_14.setText(_translate("MainWindow", "Remove"))
        self.label_7.setText(_translate("MainWindow", "--include-data-dir"))
        self.pushButton_15.setText(_translate("MainWindow", "Add"))
        self.pushButton_16.setText(_translate("MainWindow", "Remove"))
        self.label_8.setText(_translate("MainWindow", "--follow-import-to"))
        self.lineEdit_9.setText(_translate("MainWindow", "Default to the entire module"))
        self.pushButton_17.setText(_translate("MainWindow", "Remove"))
        self.pushButton_18.setText(_translate("MainWindow", "Add"))
        self.label_4.setText(_translate("MainWindow", "  Icons"))
        self.lineEdit_6.setText(_translate("MainWindow", "Select  icon"))
        self.pushButton_19.setText(_translate("MainWindow", "Remove"))
        self.pushButton_20.setText(_translate("MainWindow", "Add"))
        self.radioButton.setText(_translate("MainWindow", "windows"))
        self.radioButton_2.setText(_translate("MainWindow", "console"))
        self.pushButton_7.setText(_translate("MainWindow", "Start package"))
        self.pushButton_8.setText(_translate("MainWindow", "Stop"))
        self.pushButton_9.setText(_translate("MainWindow", "Quite"))
        self.label.setText(_translate("MainWindow", "Main File/Module"))
        self.pushButton.setText(_translate("MainWindow", "choose"))
        self.label_2.setText(_translate("MainWindow", "OutPut Path          "))
        self.pushButton_2.setText(_translate("MainWindow", "choose"))
        self.groupBox_3.setTitle(_translate("MainWindow", "other plugin"))
        self.checkBox_11.setText(_translate("MainWindow", "--include-plugin-matplotlib"))
        self.checkBox_13.setText(_translate("MainWindow", "--include-plugin-pyqt6"))
        self.checkBox_15.setText(_translate("MainWindow", "--include-plugin-pyside2"))
        self.checkBox_12.setText(_translate("MainWindow", "--include-plugin-pyside6"))
        self.checkBox_18.setText(_translate("MainWindow", "--include-plugin-no-qt5"))
        self.checkBox_19.setText(_translate("MainWindow", "--include-plugin-tensorflow"))
        self.checkBox_22.setText(_translate("MainWindow", "--include-plugin-upx"))
        self.checkBox_23.setText(_translate("MainWindow", "--include-plugin-trio"))
        self.checkBox_24.setText(_translate("MainWindow", "--include-plugin-tk-inter"))
        self.checkBox_25.setText(_translate("MainWindow", "--include-plugin-pywebview"))
        self.checkBox_14.setText(_translate("MainWindow", "--include-plugin-multiprocessing"))
        self.menu.setTitle(_translate("MainWindow", "File"))
        self.menu_2.setTitle(_translate("MainWindow", "Edit"))
        self.menu_3.setTitle(_translate("MainWindow", "Setting"))
        self.menu_4.setTitle(_translate("MainWindow", "Help"))




from setuptools import find_packages, setup

name = 'EasyNuitka'
with open(r'./requirements.txt', 'r', encoding='utf8') as f:
    requires_list = f.readlines()
    requires_list = [i.strip() for i in requires_list]
    f.close()



setup(
    name=name,  # 包名同工程名，这样导入包的时候更有对应性
    version='1.1.2.2',
    author="Loujiand",
    author_email='loujiand@gmail.com',
    description="EasyNuitka Tool",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    packages=find_packages(),
    package_data={"": ["*"]},  # 数据文件全部打包
    include_package_data=True,  # 自动包含受版本控制(svn/git)的数据文件
    url="https://github.com/qunat/EasyNuitka.git",
    zip_safe=False,
    # 设置依赖包
    install_requires=requires_list,
    classifiers=[
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: MIT License",
    "Operating System :: OS Independent",
    ]
)

#–name 包名称
#–version (-V) 包版本
#–author 程序的作者
#–author_email 程序的作者的邮箱地址
#–maintainer 维护者
#–maintainer_email 维护者的邮箱地址
#–url 程序的官网地址
#–license 程序的授权信息
#–description 程序的简单描述
#–long_description 程序的详细描述
#–platforms 程序适用的软件平台列表
#–classifiers 程序的所属分类列表
#–keywords 程序的关键字列表
#–packages 需要处理的包目录（包含__init__.py的文件夹）
#–py_modules 需要打包的python文件列表
#–download_url 程序的下载地址
#–cmdclass
#–data_files 打包时需要打包的数据文件，如图片，配置文件等
#–scripts 安装时需要执行的脚步列表
#–package_dir 告诉setuptools哪些目录下的文件被映射到哪个源码包。一个例子：package_dir = {’’: ‘lib’}，表示“root package”中的模块都在lib 目录中。
#–requires 定义依赖哪些模块
#–provides定义可以为哪些模块提供依赖
#–find_packages() 对于简单工程来说，手动增加packages参数很容易，刚刚我们用到了这个函数，它默认在和setup.py同一目录下搜索各个含有 init.py的包。
#其实我们可以将包统一放在一个src目录中，另外，这个包内可能还有aaa.txt文件和data数据文件夹。另外，也可以排除一些特定的包
#find_packages(exclude=[".tests", ".tests.", "tests.", “tests”])
#–install_requires = [“requests”] 需要安装的依赖包
#–entry_points 动态发现服务和插件，下面详细讲
